==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/kitchen/dialogs_es.lua <==

dialogId("kuch-m-objev0", "font_small", "Oh my, this is a nice kitchen.")
dialogStr("Oh, pero que linda cocina.")


dialogId("kuch-m-objev1", "font_small", "Yeah, we discovered the ship kitchen.")
dialogStr("Si, descubrimos la cocina del barco.")


dialogId("kuch-m-objev2", "font_small", "Darned kitchen.")
dialogStr("Maldita cocina.")


dialogId("kuch-m-objev3", "font_small", "And now we are in the captain Silver`s kitchen.")
dialogStr("Y ahora estamos en la cocina del capitán Silver.")


dialogId("kuch-v-varil", "font_big", "I don`t think he was a cook himself.")
dialogStr("No creo que él haya sido cocinero.")


dialogId("kuch-v-problem", "font_big", "But this is not our problem.")
dialogStr("Pero ese no es nuestro problema.")


dialogId("kuch-m-noproblem", "font_small", "There are not many problems here. I can swim out at once.")
dialogStr("No hay muchos problemas aquí. Puedo salir nadando ahora mismo.")


dialogId("kuch-v-podivej", "font_big", "But just have a look at me.")
dialogStr("Pero mira hacia acá un poco.")


dialogId("kuch-v-stolky0", "font_big", "I can`t understand how these serving tables got there.")
dialogStr("No puedo entender como esas tablas llegaron allí.")


dialogId("kuch-v-stolky1", "font_big", "These tables are in the way.")
dialogStr("Esas tablas están bloqueando el camino.")


dialogId("kuch-v-stolky2", "font_big", "This little chamber gives me the creeps.")
dialogStr("Ese pequeño compartimento me da escalofríos.")


dialogId("kuch-v-odsud0", "font_big", "I can`t get out of here!")
dialogStr("¡No puedo salir de aquí!")


dialogId("kuch-m-premyslim0", "font_small", "I`m just thinking how to help you.")
dialogStr("Sólo estoy pensando en como ayudarte.")


dialogId("kuch-v-odsud1", "font_big", "Help me somehow!")
dialogStr("¡Ayúdame de alguna forma!")


dialogId("kuch-m-premyslim1", "font_small", "I am thinking...")
dialogStr("Estoy pensando...")


dialogId("kuch-m-premyslim2", "font_small", "I am on my way.")
dialogStr("Voy para allá.")


dialogId("kuch-m-hrnec0", "font_small", "Yuck, there is something left in this pot!")
dialogStr("Que asco, hay algo que quedó en este recipiente.")


dialogId("kuch-m-hrnec1", "font_small", "This pot wasn`t even washed up.")
dialogStr("Este recipiente ni siquiera ha sido lavado.")


dialogId("kuch-m-hrnec2", "font_small", "Nobody washes the dishes here.")
dialogStr("Nadie lava los platos aquí.")


dialogId("kuch-v-kreslo0", "font_big", "If there was no chair, it would save us a lot of work.")
dialogStr("Si la silla no estuviera, nos ahorraríamos mucho trabajo.")


dialogId("kuch-v-ja", "font_big", "Especially myself.")
dialogStr("Especialmente yo.")


dialogId("kuch-m-kreslo0", "font_small", "What is a chair doing in a kitchen?")
dialogStr("¿Qué hace una silla en una cocina?")


dialogId("kuch-v-kreslo1", "font_big", "There should be no chairs in the kitchen.")
dialogStr("No deberían de haber sillas en las cocinas.")


dialogId("kuch-m-kreslo2", "font_small", "Everybody wants to rest sometimes.")
dialogStr("Todos quieren descansar algunas veces.")


dialogId("kuch-m-stolky", "font_small", "I have seen these tables somewhere.")
dialogStr("He visto esas tablas en alguna parte.")


dialogId("kuch-v-serie", "font_big", "They are mass-produced, you know.")
dialogStr("Esas son producidas en cantidad, tu sabes.")


dialogId("kuch-m-pekne", "font_small", "But they are nice. We should order a few too.")
dialogStr("Pero son lindas. Deberíamos pedir unas pocas, también.")


dialogId("kuch-v-obavam", "font_big", "I am afraid that only I can get out of this space.")
dialogStr("Me temo que solo yo puedo salir de este espacio.")


dialogId("kuch-m-zapeklite", "font_small", "It seems that even this ship contains some demanding problems.")
dialogStr("Parece que incluso este barco tiene problemas importantes.")


dialogId("kuch-v-mec", "font_big", "Why is that sword here?")
dialogStr("¿Porqué está esa espada ahí?")


dialogId("kuch-m-porcovani", "font_small", "Maybe they used it to cut the meat.")
dialogStr("Quizás la usaban para cortar la carne.")


dialogId("kuch-v-nedela", "font_big", "Certainly. But you don`t cut meat with a sword in the kitchen, usually.")
dialogStr("Seguro. Pero tu usualmente no cortas carne con una espada en la cocina.")


dialogId("kuch-m-kuchari", "font_small", "We are lucky there are no cooks here. They could try to cook us.")
dialogStr("Tenemos suerte de que no hayan cocineros aquí. Nos podrían cocinar.")


dialogId("kuch-v-svitek0", "font_big", "There must be some recipe on that parchment.")
dialogStr("Debe de haber alguna receta en ese pergamino.")


dialogId("kuch-v-svitek1", "font_big", "There must be some culinary mystery on that parchment.")
dialogStr("Debe de haber algún misterio culinario en ese pergamino.")


dialogId("kuch-m-recept", "font_small", "Possibly, how to cook the fish.")
dialogStr("Posiblemente, como cocinar al pez.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/kitchen/dialogs_es.lua <==

dialogId("kuch-m-objev0", "font_small", "Oh my, this is a nice kitchen.")
dialogStr("Oh, pero que linda cocina.")


dialogId("kuch-m-objev1", "font_small", "Yeah, we discovered the ship kitchen.")
dialogStr("Si, descubrimos la cocina del barco.")


dialogId("kuch-m-objev2", "font_small", "Darned kitchen.")
dialogStr("Maldita cocina.")


dialogId("kuch-m-objev3", "font_small", "And now we are in the captain Silver’s kitchen.")
dialogStr("Y ahora estamos en la cocina del capitán Silver.")


dialogId("kuch-v-varil", "font_big", "I don’t think he was a cook himself.")
dialogStr("No creo que él haya sido cocinero.")


dialogId("kuch-v-problem", "font_big", "But this is not our problem.")
dialogStr("Pero ese no es nuestro problema.")


dialogId("kuch-m-noproblem", "font_small", "There are not many problems here. I can swim out at once.")
dialogStr("No hay muchos problemas aquí. Puedo salir nadando ahora mismo.")


dialogId("kuch-v-podivej", "font_big", "But just have a look at me.")
dialogStr("Pero mira hacia acá un poco.")


dialogId("kuch-v-stolky0", "font_big", "I can’t understand how these serving tables got there.")
dialogStr("No puedo entender como esas tablas llegaron allí.")


dialogId("kuch-v-stolky1", "font_big", "These tables are in the way.")
dialogStr("Esas tablas están bloqueando el camino.")


dialogId("kuch-v-stolky2", "font_big", "This little chamber gives me the creeps.")
dialogStr("Ese pequeño compartimento me da escalofríos.")


dialogId("kuch-v-odsud0", "font_big", "I can’t get out of here!")
dialogStr("¡No puedo salir de aquí!")


dialogId("kuch-m-premyslim0", "font_small", "I’m just thinking how to help you.")
dialogStr("Sólo estoy pensando en como ayudarte.")


dialogId("kuch-v-odsud1", "font_big", "Help me somehow!")
dialogStr("¡Ayúdame de alguna forma!")


dialogId("kuch-m-premyslim1", "font_small", "I am thinking...")
dialogStr("Estoy pensando...")


dialogId("kuch-m-premyslim2", "font_small", "I am on my way.")
dialogStr("Voy para allá.")


dialogId("kuch-m-hrnec0", "font_small", "Yuck, there is something left in this pot!")
dialogStr("Que asco, hay algo que quedó en este recipiente.")


dialogId("kuch-m-hrnec1", "font_small", "This pot wasn’t even washed up.")
dialogStr("Este recipiente ni siquiera ha sido lavado.")


dialogId("kuch-m-hrnec2", "font_small", "Nobody washes the dishes here.")
dialogStr("Nadie lava los platos aquí.")


dialogId("kuch-v-kreslo0", "font_big", "If there was no chair, it would save us a lot of work.")
dialogStr("Si la silla no estuviera, nos ahorraríamos mucho trabajo.")


dialogId("kuch-v-ja", "font_big", "Especially myself.")
dialogStr("Especialmente yo.")


dialogId("kuch-m-kreslo0", "font_small", "What is a chair doing in a kitchen?")
dialogStr("¿Qué hace una silla en una cocina?")


dialogId("kuch-v-kreslo1", "font_big", "There should be no chairs in the kitchen.")
dialogStr("No deberían de haber sillas en las cocinas.")


dialogId("kuch-m-kreslo2", "font_small", "Everybody wants to rest sometimes.")
dialogStr("Todos quieren descansar algunas veces.")


dialogId("kuch-m-stolky", "font_small", "I have seen these tables somewhere.")
dialogStr("He visto esas tablas en alguna parte.")


dialogId("kuch-v-serie", "font_big", "They are mass-produced, you know.")
dialogStr("Esas son producidas en cantidad, tu sabes.")


dialogId("kuch-m-pekne", "font_small", "But they are nice. We should order a few too.")
dialogStr("Pero son lindas. Deberíamos pedir unas pocas, también.")


dialogId("kuch-v-obavam", "font_big", "I am afraid that only I can get out of this space.")
dialogStr("Me temo que solo yo puedo salir de este espacio.")


dialogId("kuch-m-zapeklite", "font_small", "It seems that even this ship contains some demanding problems.")
dialogStr("Parece que incluso este barco tiene problemas importantes.")


dialogId("kuch-v-mec", "font_big", "Why is that sword here?")
dialogStr("¿Porqué está esa espada ahí?")


dialogId("kuch-m-porcovani", "font_small", "Maybe they used it to cut the meat.")
dialogStr("Quizás la usaban para cortar la carne.")


dialogId("kuch-v-nedela", "font_big", "Certainly. But you don’t cut meat with a sword in the kitchen, usually.")
dialogStr("Seguro. Pero tu usualmente no cortas carne con una espada en la cocina.")


dialogId("kuch-m-kuchari", "font_small", "We are lucky there are no cooks here. They could try to cook us.")
dialogStr("Tenemos suerte de que no hayan cocineros aquí. Nos podrían cocinar.")


dialogId("kuch-v-svitek0", "font_big", "There must be some recipe on that parchment.")
dialogStr("Debe de haber alguna receta en ese pergamino.")


dialogId("kuch-v-svitek1", "font_big", "There must be some culinary mystery on that parchment.")
dialogStr("Debe de haber algún misterio culinario en ese pergamino.")


dialogId("kuch-m-recept", "font_small", "Possibly, how to cook the fish.")
dialogStr("Posiblemente, como cocinar al pez.")
